==> huaweicloudsdkrds-3.0.45-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/delete_sqlserver_database_request.py <==
# coding: utf-8

import pprint
import re

import six





class DeleteSqlserverDatabaseRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'instance_id': 'str',
        'db_name': 'str'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'instance_id': 'instance_id',
        'db_name': 'db_name'
    }

    def __init__(self, x_language=None, instance_id=None, db_name=None):
        """DeleteSqlserverDatabaseRequest - a model defined in huaweicloud sdk"""
        
        

        self._x_language = None
        self._instance_id = None
        self._db_name = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        self.instance_id = instance_id
        self.db_name = db_name

    @property
    def x_language(self):
        """Gets the x_language of this DeleteSqlserverDatabaseRequest.

        语言

        :return: The x_language of this DeleteSqlserverDatabaseRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        """Sets the x_language of this DeleteSqlserverDatabaseRequest.

        语言

        :param x_language: The x_language of this DeleteSqlserverDatabaseRequest.
        :type: str
        """
        self._x_language = x_language

    @property
    def instance_id(self):
        """Gets the instance_id of this DeleteSqlserverDatabaseRequest.

        实例ID。

        :return: The instance_id of this DeleteSqlserverDatabaseRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this DeleteSqlserverDatabaseRequest.

        实例ID。

        :param instance_id: The instance_id of this DeleteSqlserverDatabaseRequest.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def db_name(self):
        """Gets the db_name of this DeleteSqlserverDatabaseRequest.

        需要删除的数据库名。

        :return: The db_name of this DeleteSqlserverDatabaseRequest.
        :rtype: str
        """
        return self._db_name

    @db_name.setter
    def db_name(self, db_name):
        """Sets the db_name of this DeleteSqlserverDatabaseRequest.

        需要删除的数据库名。

        :param db_name: The db_name of this DeleteSqlserverDatabaseRequest.
        :type: str
        """
        self._db_name = db_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSqlserverDatabaseRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrds-3.0.49-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/delete_sqlserver_database_request.py <==
# coding: utf-8

import pprint
import re

import six





class DeleteSqlserverDatabaseRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'instance_id': 'str',
        'db_name': 'str',
        'body': 'DropDatabaseV3Req'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'instance_id': 'instance_id',
        'db_name': 'db_name',
        'body': 'body'
    }

    def __init__(self, x_language=None, instance_id=None, db_name=None, body=None):
        """DeleteSqlserverDatabaseRequest - a model defined in huaweicloud sdk"""
        
        

        self._x_language = None
        self._instance_id = None
        self._db_name = None
        self._body = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        self.instance_id = instance_id
        self.db_name = db_name
        if body is not None:
            self.body = body

    @property
    def x_language(self):
        """Gets the x_language of this DeleteSqlserverDatabaseRequest.

        语言

        :return: The x_language of this DeleteSqlserverDatabaseRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        """Sets the x_language of this DeleteSqlserverDatabaseRequest.

        语言

        :param x_language: The x_language of this DeleteSqlserverDatabaseRequest.
        :type: str
        """
        self._x_language = x_language

    @property
    def instance_id(self):
        """Gets the instance_id of this DeleteSqlserverDatabaseRequest.

        实例ID。

        :return: The instance_id of this DeleteSqlserverDatabaseRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this DeleteSqlserverDatabaseRequest.

        实例ID。

        :param instance_id: The instance_id of this DeleteSqlserverDatabaseRequest.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def db_name(self):
        """Gets the db_name of this DeleteSqlserverDatabaseRequest.

        需要删除的数据库名。

        :return: The db_name of this DeleteSqlserverDatabaseRequest.
        :rtype: str
        """
        return self._db_name

    @db_name.setter
    def db_name(self, db_name):
        """Sets the db_name of this DeleteSqlserverDatabaseRequest.

        需要删除的数据库名。

        :param db_name: The db_name of this DeleteSqlserverDatabaseRequest.
        :type: str
        """
        self._db_name = db_name

    @property
    def body(self):
        """Gets the body of this DeleteSqlserverDatabaseRequest.


        :return: The body of this DeleteSqlserverDatabaseRequest.
        :rtype: DropDatabaseV3Req
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this DeleteSqlserverDatabaseRequest.


        :param body: The body of this DeleteSqlserverDatabaseRequest.
        :type: DropDatabaseV3Req
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSqlserverDatabaseRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
